<?php
/**
 * @file
 * Main view template.
 *
 * Variables available:
 * - $classes_array: An array of classes determined in
 *   template_preprocess_views_view(). Default classes are:
 *     .view
 *     .view-[css_name]
 *     .view-id-[view_name]
 *     .view-display-id-[display_name]
 *     .view-dom-id-[dom_id]
 * - $classes: A string version of $classes_array for use in the class attribute
 * - $css_name: A css-safe version of the view name.
 * - $css_class: The user-specified classes names, if any
 * - $header: The view header
 * - $footer: The view footer
 * - $rows: The results of the view query, if any
 * - $empty: The empty text to display if the view is empty
 * - $pager: The pager next/prev links to display, if any
 * - $exposed: Exposed widget form/info to display
 * - $feed_icon: Feed icon to display, if any
 * - $more: A link to view more, if any
 *
 * @ingroup views_templates
 */
?>
<div class="<?php print $classes; ?>">
  <?php print render($title_prefix); ?>
  <?php if ($title): ?>
    <?php print $title; ?>
  <?php endif; ?>
  <?php print render($title_suffix); ?>
  <?php global $base_url; ?>
  <div class="view-header">
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/front/solar-energy-small.png" media="(max-width: 600px)">
          <img src="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/front/solar-energy.png" alt="Urban Development" />
          </source>
      </picture>
    <?php print $header; ?>
  </div>
  <?php if ($exposed): ?>
    <div class="view-filters">
      <?php print $exposed; ?>
    </div>
  <?php endif; ?>

  <?php if ($attachment_before): ?>
    <div class="attachment attachment-before">
      <?php print $attachment_before; ?>
    </div>
  <?php endif; ?>

  <?php if ($rows): ?>
    <div class="view-content">
      <?php print $rows; ?>
    </div>
  <?php elseif ($empty): ?>
    <div class="view-empty">
      <?php print $empty; ?>
    </div>
  <?php endif; ?>

  <?php if ($pager): ?>
    <?php print $pager; ?>
  <?php endif; ?>

  <?php if ($attachment_after): ?>
    <div class="attachment attachment-after">
      <?php print $attachment_after; ?>
    </div>
  <?php endif; ?>

  <?php if ($more): ?>
    <?php print $more; ?>
  <?php endif; ?>

  <?php if ($footer): ?>
    <div class="view-footer">
      <?php print $footer; ?>
    </div>
  <?php endif; ?>

  <h2>BSC Mineral Dust Model</h2>
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/default/files/imce/ojofv8dzd_w-vaida-tamosauskaite.jpg" media="(max-width: 600px)">
          <img class="img-success-story" src="<?php print $base_url; ?>/sites/default/files/imce/ojofv8dzd_w-vaida-tamosauskaite.jpg" alt="BSC Mineral Dust Model" />
          </source>
      </picture>
      <p>The NMMB/BSC Chemical Transport Model is an online multi-scale chemical weather prediction system developed by the Mineral Dust group at BSC. It can be run globally or regionally. The model’s mineral dust component is run operationally at the World Meteorological Organization (WMO) Regional Specialized Meteorological Center for Atmospheric Sand and Dust Forecast (http://sds-was.aemet.es/). Together with the sea salt component, the model also contributes to the International Cooperative for Aerosol Prediction (ICAP) model initiative (http://icap.atmos.und.edu/). In addition, the Mineral Dust Group provides daily operational forecasts of mineral dust for North Africa, Middle East, Europe and East Asia based on the updated version of the BSC-DREAM8b Atmospheric Dust Forecast System. This system is coupled offline with CALIOPE, a unique operational air quality forecasting system for Europe, which includes the contribution of Saharan dust on an hourly basis. BSC models are used in the WMO Sand and Dust Storm Warning Advisory and Assessment system (SDS-WAS) in the Regional Centre for Northern Africa, Middle East and Europe hosted by BSC and AEMET (http://sds-was.aemet.es/).</p>

  <h2>Barcelona Dust Forecast Center</h2>

  <p>The Barcelona Dust Forecast Center is the first WMO Regional Specialized Metereological Center with activity specialization on atmospheric Sand and Dust Forecast (RSMC-ASDF). The center operationally generates and distributes dust operational products for Northern Africa, Middle East and Europe (http://dust.aemet.es/)</p>

      <h2>Partners and collaborators</h2>
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/partners.png" media="(max-width: 600px)">
          <img src="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/partners.png" alt="Partners and collaborators" />
          </source>
      </picture>

      <h2>Projects</h2>
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/projects.png" media="(max-width: 600px)">
          <img src="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/projects.png" alt="Projects" />
          </source>
      </picture>


  <?php if ($feed_icon): ?>
    <div class="feed-icon">
      <?php print $feed_icon; ?>
    </div>
  <?php endif; ?>

</div><?php /* class view */ ?>
